[PATCH 3/3] MIPS: rename pbl_main_entry() -> barebox_pbl_start()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Unify function and file names with ARM and RISC-V.

Signed-off-by: Antony Pavlov <antonynpavlov@xxxxxxxxx>
---
 arch/mips/boards/board-dt-2nd.S                   | 4 ++--
 arch/mips/boards/netgear-wg102/lowlevel.S         | 2 +-
 arch/mips/boot/Makefile                           | 2 +-
 arch/mips/boot/{main_entry-pbl.c => uncompress.c} | 6 +++---
 arch/mips/include/asm/asm.h                       | 2 +-
 5 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/arch/mips/boards/netgear-wg102/lowlevel.S b/arch/mips/boards/netgear-wg102/lowlevel.S
index 6fdcfa3ccae..3d9715e8fc7 100644
--- a/arch/mips/boards/netgear-wg102/lowlevel.S
+++ b/arch/mips/boards/netgear-wg102/lowlevel.S
@@ -61,7 +61,7 @@ sdram_configured:
 	stack_setup;
 
 	lw	a0, 0;
-	la	v0, pbl_main_entry;
+	la	v0, barebox_pbl_start;
 	jal	v0;
 	 nop;
 
diff --git a/arch/mips/boot/Makefile b/arch/mips/boot/Makefile
index d1e27b5e6b8..da3f53d3123 100644
--- a/arch/mips/boot/Makefile
+++ b/arch/mips/boot/Makefile
@@ -5,4 +5,4 @@ obj-y += main_entry.o
 
 obj-$(CONFIG_OFDEVICE) += dtb.o
 
-pbl-y += main_entry-pbl.o
+pbl-y += uncompress.o
diff --git a/arch/mips/boot/main_entry-pbl.c b/arch/mips/boot/uncompress.c
similarity index 87%
rename from arch/mips/boot/main_entry-pbl.c
rename to arch/mips/boot/uncompress.c
index 7b5e81817e0..9344679a6b8 100644
--- a/arch/mips/boot/main_entry-pbl.c
+++ b/arch/mips/boot/uncompress.c
@@ -19,16 +19,16 @@ extern void *input_data_end;
 unsigned long free_mem_ptr;
 unsigned long free_mem_end_ptr;
 
-void pbl_main_entry(void *fdt, void *fdt_end, u32 ram_size);
+void barebox_pbl_start(void *fdt, void *fdt_end, u32 ram_size);
 
-void __section(.text_entry) pbl_main_entry(void *fdt, void *fdt_end,
+void __section(.text_entry) barebox_pbl_start(void *fdt, void *fdt_end,
 					   u32 ram_size)
 {
 	u32 piggy_len, fdt_len;
 	void *fdt_new;
 	void (*barebox)(void *fdt, u32 ram_size);
 
-	puts_ll("pbl_main_entry()\n");
+	puts_ll("barebox_pbl_start()\n");
 
 	/* clear bss */
 	memset(__bss_start, 0, __bss_stop - __bss_start);
diff --git a/arch/mips/include/asm/asm.h b/arch/mips/include/asm/asm.h
index f6daae67579..d07e26cff03 100644
--- a/arch/mips/include/asm/asm.h
+++ b/arch/mips/include/asm/asm.h
@@ -97,7 +97,7 @@ EXPORT(symbol)						\
 	PTR_LA	a0, __dtb_ ## dtb##_start;		\
 	PTR_LA	a1, __dtb_ ## dtb##_end;		\
 	PTR_LI	a2, ram_size;				\
-	PTR_LA	v0, pbl_main_entry;			\
+	PTR_LA	v0, barebox_pbl_start;			\
 	jal	v0;					\
 	 nop;						\
 							\
diff --git a/arch/mips/boards/board-dt-2nd.S b/arch/mips/boards/board-dt-2nd.S
index a1465f09e36..1e70574509c 100644
--- a/arch/mips/boards/board-dt-2nd.S
+++ b/arch/mips/boards/board-dt-2nd.S
@@ -20,12 +20,12 @@ ENTRY_FUNCTION(start_dt_2nd)
 
 	stack_setup
 
 	/* pbl_main_entry() computes fdt_len by itself
 	 * if fdt == fdt_end */
 	move	a0, v1 /* fdt */
 	move	a1, v1 /* fdt_end */
 	PTR_LI	a2, SZ_256M /* ram_size */
-	PTR_LA	v0, pbl_main_entry
+	PTR_LA	v0, barebox_pbl_start
 	jal	v0
 	 nop
 
@@ -20,12 +20,12 @@ ENTRY_FUNCTION(start_dt_2nd)
 	stack_setup
 
-	/* pbl_main_entry() computes fdt_len by itself
+	/* barebox_pbl_start() computes fdt_len by itself
 	 * if fdt == fdt_end */
 	move	a0, v1 /* fdt */
-- 
2.39.0





[Index of Archives]     [Linux Embedded]     [Linux USB Devel]     [Linux Audio Users]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]     [XFree86]

  Powered by Linux